==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/analysis/TypeAnalysis__241.h <==
// final class org.dellroad.jc.cgen.analysis.TypeAnalysis$1

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f3698f4b33505aee org_dellroad_jc_cgen_analysis_TypeAnalysis__241
// @dep_class 284aff14bea3930f soot_jimple_AbstractJimpleValueSwitch

// header file dependencies
// @dep_header soot_jimple_AbstractJimpleValueSwitch

#include "soot/jimple/AbstractJimpleValueSwitch.h"

#ifndef _JC_org_dellroad_jc_cgen_analysis_TypeAnalysis__241_H_
#define _JC_org_dellroad_jc_cgen_analysis_TypeAnalysis__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$object;
struct _jc_soot_jimple_NewArrayExpr$object;
struct _jc_soot_jimple_NewExpr$object;
struct _jc_soot_jimple_NewMultiArrayExpr$object;
struct _jc_soot_jimple_NullConstant$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$sub_refs	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$sub_nonrefs	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$refs	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$nonrefs	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object;

typedef const struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vmethods	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vtable	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vtype	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$method$_init$d51f786e98bd36e3(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$object *);

// Virtual methods
extern void _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$method$caseNewArrayExpr$a253d21e8d16d4b1(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object *, struct _jc_object *);
extern void _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$method$caseNewExpr$a19e03ca0d8a8f14(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object *, struct _jc_object *);
extern void _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$method$caseNewMultiArrayExpr$517ba3e177c22c7f(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object *, struct _jc_object *);
extern void _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$method$caseNullConstant$bc52edd8a3808260(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object *, struct _jc_soot_jimple_NullConstant$object *);
extern void _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$method$defaultCase$6711cf3c099fadd1(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$method_info$caseNewArrayExpr$a253d21e8d16d4b1;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$method_info$caseNewExpr$a19e03ca0d8a8f14;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$method_info$caseNewMultiArrayExpr$517ba3e177c22c7f;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$method_info$caseNullConstant$bc52edd8a3808260;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$method_info$defaultCase$6711cf3c099fadd1;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vmethods {
	void	(*caseNewArrayExpr$a253d21e8d16d4b1)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object *, struct _jc_object *);
	void	(*caseNewExpr$a19e03ca0d8a8f14)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object *, struct _jc_object *);
	void	(*caseNewMultiArrayExpr$517ba3e177c22c7f)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object *, struct _jc_object *);
	void	(*caseNullConstant$bc52edd8a3808260)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object *, struct _jc_soot_jimple_NullConstant$object *);
	void	(*defaultCase$6711cf3c099fadd1)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractJimpleValueSwitch$vmethods	soot_jimple_AbstractJimpleValueSwitch;
	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vmethods	org_dellroad_jc_cgen_analysis_TypeAnalysis__241;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$sub_refs {
	struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$object	*this;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$refs {
    _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$sub_refs	org_dellroad_jc_cgen_analysis_TypeAnalysis__241;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_refs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_nonrefs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$sub_nonrefs	org_dellroad_jc_cgen_analysis_TypeAnalysis__241;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object {
	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vtype _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_analysis_TypeAnalysis__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_analysis_TypeAnalysis__241_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/analysis/TypeAnalysis__241.h <==
// final class org.dellroad.jc.cgen.analysis.TypeAnalysis$1

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f3698f4b33505aee org_dellroad_jc_cgen_analysis_TypeAnalysis__241
// @dep_class 284aff14bea3930f soot_jimple_AbstractJimpleValueSwitch

// header file dependencies
// @dep_header soot_jimple_AbstractJimpleValueSwitch

#include "soot/jimple/AbstractJimpleValueSwitch.h"

#ifndef _JC_org_dellroad_jc_cgen_analysis_TypeAnalysis__241_H_
#define _JC_org_dellroad_jc_cgen_analysis_TypeAnalysis__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$object;
struct _jc_soot_jimple_NewArrayExpr$object;
struct _jc_soot_jimple_NewExpr$object;
struct _jc_soot_jimple_NewMultiArrayExpr$object;
struct _jc_soot_jimple_NullConstant$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$sub_refs	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$sub_nonrefs	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$refs	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$nonrefs	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object;

typedef const struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vmethods	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vtable	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vtype	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$method$_init$d51f786e98bd36e3(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$method$caseNewArrayExpr$a253d21e8d16d4b1(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$method$caseNewExpr$a19e03ca0d8a8f14(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$method$caseNewMultiArrayExpr$517ba3e177c22c7f(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$method$caseNullConstant$bc52edd8a3808260(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object *, struct _jc_soot_jimple_NullConstant$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$method$defaultCase$6711cf3c099fadd1(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$method_info$caseNewArrayExpr$a253d21e8d16d4b1;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$method_info$caseNewExpr$a19e03ca0d8a8f14;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$method_info$caseNewMultiArrayExpr$517ba3e177c22c7f;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$method_info$caseNullConstant$bc52edd8a3808260;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$method_info$defaultCase$6711cf3c099fadd1;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vmethods {
	void	(*caseNewArrayExpr$a253d21e8d16d4b1)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseNewExpr$a19e03ca0d8a8f14)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseNewMultiArrayExpr$517ba3e177c22c7f)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseNullConstant$bc52edd8a3808260)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object *, struct _jc_soot_jimple_NullConstant$object *) _JC_JCNI_ATTR;
	void	(*defaultCase$6711cf3c099fadd1)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractJimpleValueSwitch$vmethods	soot_jimple_AbstractJimpleValueSwitch;
	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vmethods	org_dellroad_jc_cgen_analysis_TypeAnalysis__241;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$sub_refs {
	struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis$object	*this;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$refs {
    _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$sub_refs	org_dellroad_jc_cgen_analysis_TypeAnalysis__241;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_refs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_nonrefs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$sub_nonrefs	org_dellroad_jc_cgen_analysis_TypeAnalysis__241;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$object {
	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$vtype _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_analysis_TypeAnalysis__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_analysis_TypeAnalysis__241$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_analysis_TypeAnalysis__241_H_ */
